--
-- A simulation model of Bally Astrocade hardware
-- Copyright (c) MikeJ - Nov 2004
--
-- All rights reserved
--
-- Redistribution and use in source and synthezised forms, with or without
-- modification, are permitted provided that the following conditions are met:
--
-- Redistributions of source code must retain the above copyright notice,
-- this list of conditions and the following disclaimer.
--
-- Redistributions in synthesized form must reproduce the above copyright
-- notice, this list of conditions and the following disclaimer in the
-- documentation and/or other materials provided with the distribution.
--
-- Neither the name of the author nor the names of other contributors may
-- be used to endorse or promote products derived from this software without
-- specific prior written permission.
--
-- THIS CODE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
-- AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
-- THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
-- PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE
-- LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
-- CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
-- SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
-- INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
-- CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
-- ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
-- POSSIBILITY OF SUCH DAMAGE.
--
-- You are responsible for any legal issues arising from your use of this code.
--
-- The latest version of this file can be found at: www.fpgaarcade.com
--
-- Email support@fpgaarcade.com
--
-- Revision list
--
-- version 003 spartan3e release
-- version 001 initial release
--
library ieee;
  use ieee.std_logic_1164.all;
  use ieee.std_logic_arith.all;
  use ieee.std_logic_unsigned.all;

library UNISIM;
  use UNISIM.Vcomponents.all;

entity BALLY_RAMS is
  port (
  ADDR     : in  std_logic_vector(11 downto 0);
  DIN      : in  std_logic_vector(7 downto 0);
  DOUT     : out std_logic_vector(7 downto 0);
  WE       : in  std_logic;
  WE_ENA_L : in  std_logic; -- used for write enable gate only
  ENA      : in  std_logic;
  CLK      : in  std_logic
  );
end;

architecture RTL of BALLY_RAMS is
  signal dout_int : std_logic_vector(7 downto 0);
  signal int_we : std_logic;

begin
  --rams : for i in 0 to 1 generate
  --begin
    ram_u : RAMB16_S4
      port map (
        DO     => dout_int(7 downto 4),
        DI     => DIN(7 downto 4),
        ADDR   => ADDR(11 downto 0),
        WE     => int_we,
        EN     => ENA,
        SSR    => '0',
        CLK    => CLK
        );

    ram_l : RAMB16_S4
      port map (
        DO     => dout_int(3 downto 0),
        DI     => DIN(3 downto 0),
        ADDR   => ADDR(11 downto 0),
        WE     => int_we,
        EN     => ENA,
        SSR    => '0',
        CLK    => CLK
        );
  --end generate;

  p_mux : process(dout_int, addr)
  begin
    dout <= dout_int;
  end process;

  p_we : process(WE, WE_ENA_L)
  begin
    int_we <= WE and not WE_ENA_L;
  end process;

end architecture RTL;
